# mypy-boto3-sqs

[![PyPI - mypy-boto3-sqs](https://img.shields.io/pypi/v/mypy-boto3-sqs.svg?color=blue)](https://pypi.org/project/mypy-boto3-sqs)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/mypy-boto3-sqs.svg?color=blue)](https://pypi.org/project/mypy-boto3-sqs)
[![Docs](https://img.shields.io/readthedocs/mypy-boto3-builder.svg?color=blue)](https://mypy-boto3-builder.readthedocs.io/)

Type annotations for
[boto3.SQS 1.14.38](https://boto3.amazonaws.com/v1/documentation/api/1.14.38/reference/services/sqs.html#SQS) service
compatible with [mypy](https://github.com/python/mypy), [VSCode](https://code.visualstudio.com/),
[PyCharm](https://www.jetbrains.com/pycharm/) and other tools.

Generated by [mypy-boto3-buider 2.2.0](https://github.com/vemel/mypy_boto3_builder).

More information can be found on [boto3-stubs](https://pypi.org/project/boto3-stubs/) page.

## How to install

Make sure you have [mypy](https://github.com/python/mypy) installed and activated in your IDE.

Install `boto3-stubs` for `SQS` service.

```bash
python -m pip install boto3-stubs[sqs]
```

## How to use

### Client annotations

`SQSClient` provides annotations for `boto3.client("sqs")`.

```python
import boto3

from mypy_boto3_sqs import SQSClient, SQSServiceResource
from mypy_boto3_sqs.paginator import ListDeadLetterSourceQueuesPaginator, ListQueuesPaginator
from mypy_boto3_sqs.service_resource import Message, Queue, ServiceResourceQueuesCollection
from mypy_boto3_sqs.type_defs import BatchResultErrorEntryTypeDef, ...

client: SQSClient = boto3.client("sqs")

# now client usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_client: SQSClient = session.client("sqs")
```

### Paginators annotations

`mypy_boto3_sqs.paginator` module contains type annotations for all paginators.

```python

client: SQSClient = boto3.client("sqs")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
# VSCode requires explicit type annotations
list_dead_letter_source_queues_paginator: ListDeadLetterSourceQueuesPaginator = client.get_paginator("list_dead_letter_source_queues")
list_queues_paginator: ListQueuesPaginator = client.get_paginator("list_queues")
```




### Service Resource annotations

`SQSServiceResource` provides annotations for `boto3.resource("sqs")`.

```python

resource: SQSServiceResource = boto3.resource("sqs")

# now resource usage is checked by mypy and IDE should provide code auto-complete

# works for session as well
session = boto3.session.Session(region="us-west-1")
session_resource: SQSServiceResource = session.resource("sqs")
```


### Other resources annotations

`mypy_boto3_sqs.service_resource` module contains type annotations for all resources.

```python

resource: SQSServiceResource = boto3.resource("sqs")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
my_message: Message = resource.Message(...)
my_queue: Queue = resource.Queue(...)
```



### Collections annotations

`mypy_boto3_sqs.service_resource` module contains type annotations
for all `SQSServiceResource` collections.

```python

resource: SQSServiceResource = boto3.resource("sqs")

# Explicit type annotations are optional here
# Type should be correctly discovered by mypy and IDEs
queues: sqs_resources.ServiceResourceQueuesCollection = resource.queues
```




### Typed dictionations

`mypy_boto3_sqs.type_defs` module contains structures and shapes assembled
to typed dictionaries for additional type checking.

```python

def get_structure() -> BatchResultErrorEntryTypeDef:
    return {
      ...
    }
```


## Dynamic type annotations

`mypy_boto3` command generates `boto3.client/resource` type annotations for
`mypy_boto3_sqs` and other installed services.

```bash
# Run this command after you add or remove service packages
python -m mypy_boto3
```

Generated type annotations provide overloads for `boto3.client` and `boto3.resource`,
`boto3.Session.client` and `boto3.Session.resource` functions,
so explicit type annotations are not needed.

- `mypy` supports function overloads as expected
- `PyCharm` also supports function overloads, but consumes a lot of RAM, use carefully if you have many services installed
- `VSCode` does not currently support function overloads, use explicit type annotations

```python

# Type is discovered correctly by mypy and PyCharm
# VSCode still needs explicit type annotations
client = boto3.client("sqs")
resource = boto3.resource("sqs")

session_client = boto3.Session().client("sqs")
session_resource = boto3.Session().resource("sqs")
```
